Location

Struct Location 

pub struct Location<'pr> { /* private fields */ }
A range in the source file, represented as a start offset and length.

Implementations

Source

impl<'pr> Location<'pr>

pub fn as_slice(&self) -> &'pr [u8]

Returns a byte slice for the range.

pub const fn start(&self) -> u32

Returns the start offset from the beginning of the parsed source.

pub const fn end(&self) -> u32

Returns the end offset from the beginning of the parsed source.

pub fn join(&self, other: &Self) -> Option<Self>

Return a Location starting at self and ending at the end of other. Returns None if both locations did not originate from the same parser, or if self starts after other.

pub const fn chop(&self) -> Self

Returns a new location that is the result of chopping off the last byte.

Source

impl Location<'_>

pub fn start_line(&self) -> i32

Returns the line number where this location starts.

pub fn start_column(&self) -> u32

Returns the column number in bytes where this location starts from the start of the line.

pub fn end_line(&self) -> i32

Returns the line number where this location ends.

pub fn end_column(&self) -> u32

Returns the column number in bytes where this location ends from the start of the line.