pub struct Location<'pr> { /* private fields */ }Expand description
A range in the source file, represented as a start offset and length.
Implementations
Sourceimpl<'pr> Location<'pr>
impl<'pr> Location<'pr>
Sourcepub const fn start(&self) -> u32
pub const fn start(&self) -> u32
Returns the start offset from the beginning of the parsed source.
Sourceimpl Location<'_>
impl Location<'_>
Sourcepub fn start_line(&self) -> i32
pub fn start_line(&self) -> i32
Returns the line number where this location starts.
Sourcepub fn start_column(&self) -> u32
pub fn start_column(&self) -> u32
Returns the column number in bytes where this location starts from the start of the line.
Sourcepub fn end_column(&self) -> u32
pub fn end_column(&self) -> u32
Returns the column number in bytes where this location ends from the start of the line.