pub trait FullName<'pr> {
// Required method
fn full_name_parts(&self) -> Result<Vec<&'pr [u8]>, ConstantPathError>;
// Provided method
fn full_name(&self) -> Result<Vec<u8>, ConstantPathError> { ... }
}Expand description
Trait for nodes that can compute their full constant name.
Implemented by constant-related nodes (ConstantReadNode,
ConstantWriteNode, ConstantTargetNode, ConstantPathNode, and
ConstantPathTargetNode).
Required Methods
Sourcefn full_name_parts(&self) -> Result<Vec<&'pr [u8]>, ConstantPathError>
fn full_name_parts(&self) -> Result<Vec<&'pr [u8]>, ConstantPathError>
Returns the list of parts for the full name of this constant.
Errors
Returns ConstantPathError if the path contains dynamic parts or
error recovery nodes.
Provided Methods
Sourcefn full_name(&self) -> Result<Vec<u8>, ConstantPathError>
fn full_name(&self) -> Result<Vec<u8>, ConstantPathError>
Returns the full name of this constant.
Errors
Returns ConstantPathError if the path contains dynamic parts or
error recovery nodes.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".