FullName

Trait FullName 

pub trait FullName<'pr> {
    // Required method
    fn full_name_parts(&self) -> Result<Vec<&'pr [u8]>, ConstantPathError>;

    // Provided method
    fn full_name(&self) -> Result<Vec<u8>, ConstantPathError> { ... }
}
Trait for nodes that can compute their full constant name.

Implemented by constant-related nodes (ConstantReadNode, ConstantWriteNode, ConstantTargetNode, ConstantPathNode, and ConstantPathTargetNode).

Required Methods

fn full_name_parts(&self) -> Result<Vec<&'pr [u8]>, ConstantPathError>

Returns the list of parts for the full name of this constant.

Errors

Returns ConstantPathError if the path contains dynamic parts or missing nodes.

Provided Methods

fn full_name(&self) -> Result<Vec<u8>, ConstantPathError>

Returns the full name of this constant.

Errors

Returns ConstantPathError if the path contains dynamic parts or missing nodes.

Implementors

Source

impl<'pr> FullName<'pr> for ConstantPathNode<'pr>

Source

impl<'pr> FullName<'pr> for ConstantPathTargetNode<'pr>

Source

impl<'pr> FullName<'pr> for ConstantReadNode<'pr>

Source

impl<'pr> FullName<'pr> for ConstantTargetNode<'pr>

Source

impl<'pr> FullName<'pr> for ConstantWriteNode<'pr>